==> haskell-foldl-1.4.5-57-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-foldl.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: foldl
version: 1.4.5
id: foldl-1.4.5-BwSYUrYB4mCENwiycoNHFh
key: foldl-1.4.5-BwSYUrYB4mCENwiycoNHFh
license: BSD-3-Clause
copyright: 2013 Gabriel Gonzalez
maintainer: Gabriel439@gmail.com
author: Gabriel Gonzalez
synopsis: Composable, streaming, and efficient left folds
description:
    This library provides strict left folds that stream in constant
    memory, and you can combine folds using @Applicative@ style to derive new
    folds.  Derived folds still traverse the container just once and are often as
    efficient as hand-written folds.
category: Control
abi: 9708243841807cb84163491f403d7ddc
exposed: True
exposed-modules:
    Control.Foldl Control.Foldl.ByteString Control.Foldl.Text
    Control.Scanl
hidden-modules: Control.Foldl.Optics Control.Foldl.Internal
import-dirs: /usr/lib/ghc-8.6.5/site-local/foldl-1.4.5
library-dirs: /usr/lib/ghc-8.6.5/site-local/foldl-1.4.5
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/foldl-1.4.5
hs-libraries: HSfoldl-1.4.5-BwSYUrYB4mCENwiycoNHFh
depends:
    base-4.12.0.0 bytestring-0.10.8.2
    comonad-5.0.6-8rsrtEd0xc7Zvn1LuwTgB containers-0.6.0.1
    contravariant-1.5.2-IGTyLqhZC2pCTY0qng5HHQ
    hashable-1.2.7.0-KHvCgUH7dIl7mI8fl4akIo
    mwc-random-0.14.0.0-9OX8VYCuo08BrxmlBLXfTV
    primitive-0.6.4.0-ILgywxtLpvnAOlEISPpP5b
    profunctors-5.5-9DJamy7YSxgEgqnFJxy8X3
    semigroupoids-5.3.3-AQtiKPqhF0dKZgZBy40uPE text-1.2.3.1
    transformers-0.5.6.2
    unordered-containers-0.2.10.0-AdFIXUUlSRM50nV4OuQt9A
    vector-0.12.0.3-2LEYu9M2i7lERDtz76XG3n
    vector-builder-0.3.8-9BuckPT6HC47LZa0pQIJTo
haddock-interfaces: /usr/share/doc/haskell-foldl/html/foldl.haddock
haddock-html: /usr/share/doc/haskell-foldl/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-foldl-1.4.5-58-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-foldl.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: foldl
version: 1.4.5
id: foldl-1.4.5-IkEUckHHvgXLIpPgAzlCm2
key: foldl-1.4.5-IkEUckHHvgXLIpPgAzlCm2
license: BSD-3-Clause
copyright: 2013 Gabriel Gonzalez
maintainer: Gabriel439@gmail.com
author: Gabriel Gonzalez
synopsis: Composable, streaming, and efficient left folds
description:
    This library provides strict left folds that stream in constant
    memory, and you can combine folds using @Applicative@ style to derive new
    folds.  Derived folds still traverse the container just once and are often as
    efficient as hand-written folds.
category: Control
abi: c95ecf97d44f09ea4d222e020ca4bcaa
exposed: True
exposed-modules:
    Control.Foldl Control.Foldl.ByteString Control.Foldl.Text
    Control.Scanl
hidden-modules: Control.Foldl.Optics Control.Foldl.Internal
import-dirs: /usr/lib/ghc-8.6.5/site-local/foldl-1.4.5
library-dirs: /usr/lib/ghc-8.6.5/site-local/foldl-1.4.5
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/foldl-1.4.5
hs-libraries: HSfoldl-1.4.5-IkEUckHHvgXLIpPgAzlCm2
depends:
    base-4.12.0.0 bytestring-0.10.8.2
    comonad-5.0.6-8rsrtEd0xc7Zvn1LuwTgB containers-0.6.0.1
    contravariant-1.5.2-IGTyLqhZC2pCTY0qng5HHQ
    hashable-1.2.7.0-KHvCgUH7dIl7mI8fl4akIo
    mwc-random-0.14.0.0-9OX8VYCuo08BrxmlBLXfTV
    primitive-0.6.4.0-ILgywxtLpvnAOlEISPpP5b
    profunctors-5.5.1-6DNrH25YhHECVaJNHzhHZx
    semigroupoids-5.3.3-AQtiKPqhF0dKZgZBy40uPE text-1.2.3.1
    transformers-0.5.6.2
    unordered-containers-0.2.10.0-AdFIXUUlSRM50nV4OuQt9A
    vector-0.12.0.3-2LEYu9M2i7lERDtz76XG3n
    vector-builder-0.3.8-9BuckPT6HC47LZa0pQIJTo
haddock-interfaces: /usr/share/doc/haskell-foldl/html/foldl.haddock
haddock-html: /usr/share/doc/haskell-foldl/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
